@@ -1,7 +1,9 @@
 package App::xsum;
 
-our $DATE = '2019-10-20'; # DATE
-our $VERSION = '0.008'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2019-11-29'; # DATE
+our $DIST = 'App-xsum'; # DIST
+our $VERSION = '0.009'; # VERSION
 
 use 5.010001;
 use strict;
@@ -66,7 +68,7 @@ _
             cmdline_aliases => {a=>{}},
         },
         digest_args => {
-            schema => ['array*', of=>'str*', 'x.perl.coerce_rules'=>['str_comma_sep']],
+            schema => ['array*', of=>'str*', 'x.perl.coerce_rules'=>['From_str::comma_sep']],
             description => <<'_',
 
 If you use `Digest` as the algorithm, you can pass arguments for the <pm:Digest>
@@ -392,7 +394,7 @@ App::xsum - Compute and check file checksums/digests (using various algorithms)
 
 =head1 VERSION
 
-This document describes version 0.008 of App::xsum (from Perl distribution App-xsum), released on 2019-10-20.
+This document describes version 0.009 of App::xsum (from Perl distribution App-xsum), released on 2019-11-29.
 
 =head1 SYNOPSIS
 
